obj_doc_update

Function obj_doc_update 

#[unsafe(no_mangle)]
pub unsafe extern "C" fn obj_doc_update( txn: *mut obj_write_txn_t, collection: *const c_char, id: u64, payload: *const u8, payload_len: usize, ) -> obj_error_t
Update the document at id in collection with payload. Returns OBJ_ERR_NOT_FOUND if the id is absent.

Safety

As obj_doc_insert plus: id must have been returned by a prior obj_doc_insert against the same collection.