Enum obj::raw::object::Line [] [src]

pub enum Line {
    P(Vec<usize>),
    PT(Vec<(usize, usize)>),
}

The Line type.

Variants

P(Vec<usize>)

A series of line segments which contain only the position data of each vertex

PT(Vec<(usize, usize)>)

A series of line segments which contain both position and texture coordinate data of each vertex