Module obj::raw::object [−][src]
Parses .obj format which stores 3D mesh data
Structs
A group which contains ranges of points, lines and polygons
A struct which represent [start, end) range.
Low-level Rust binding for .obj format.
Enums
Functions
Parses a wavefront .obj format.
Type Definitions
The Point type which stores the index of the position vector.