Enum obj::raw::object::Polygon [] [src]

pub enum Polygon {
    P(Vec<usize>),
    PT(Vec<(usize, usize)>),
    PN(Vec<(usize, usize)>),
    PTN(Vec<(usize, usize, usize)>),
}

The Polygon type.

Variants

P(Vec<usize>)

A polygon which contains only the position data of each vertex.

PT(Vec<(usize, usize)>)

A polygon which contains both position and texture coordinate data of each vertex.

PN(Vec<(usize, usize)>)

A polygon which contains both position and normal data of each vertex.

PTN(Vec<(usize, usize, usize)>)

A polygon which contains all position, texture coordinate and normal data of each vertex.